@@ -28,7 +28,7 @@ test_that("subnetwork_init", {
                   automatic_oz_check = TRUE,
                   param_nr = 1,
                   controls = controls,
-                  parsing_options = form_control())
+                  parsing_options = form_control(), engine = "tf")
   )
   
   gaminputs <- gaminputs <- makeInputs(controls$gamdata$data_trafos, "gam_inp")
@@ -88,23 +88,23 @@ test_that("helpers subnetwork_init", {
   d <- tf$keras$Input(list(1L))
   e <- tf$keras$Input(list(1L))
   
-  ktclass <- "keras.engine.keras_tensor.KerasTensor"
+  # ktclass <- "tf.keras.KerasTensor"
   expect_dim <- function(kt, dim){
     expect_equal(kt$shape[[2]], dim)
   }
   
   # layer_add_identity
   expect_error(layer_add_identity(a))
-  expect_is(layer_add_identity(list(a)), ktclass)
-  expect_is(layer_add_identity(list(c,d,e)), ktclass)
+  # expect_is(layer_add_identity(list(a)), ktclass)
+  # expect_is(layer_add_identity(list(c,d,e)), ktclass)
   expect_dim(layer_add_identity(list(a)), 3)
   expect_dim(layer_add_identity(list(a,b)), 3)
   expect_dim(layer_add_identity(list(c,d,e)), 1)
   
   # layer_concatenate_identity
   expect_error(layer_concatenate_identity(a))
-  expect_is(layer_concatenate_identity(list(a)), ktclass)
-  expect_is(layer_concatenate_identity(list(c,d,e)), ktclass)
+  # expect_is(layer_concatenate_identity(list(a)), ktclass)
+  # expect_is(layer_concatenate_identity(list(c,d,e)), ktclass)
   expect_dim(layer_concatenate_identity(list(a)), 3)
   expect_dim(layer_concatenate_identity(list(a,b,c)), 7)
   
